% MtAddSuccessor adds a new successor to a relationship.
%
%   status = MtAddSuccessor (object, relationship, successor, where);
%   status = MtAddSuccessor (object, relationship, successor, 'MT_AFTER', element);
%
%   The location of the new successor depends on the value of the argument where:
%
%   - If where is set to 'MT_FIRST', the successor is added at the beginning of 
%     the existing list of successors. 
%   - If where is set to MT_APPEND, the successor is added at the end of the 
%     existing list of successors. 
%   - If where is set to MT_AFTER, the successor is added after the successor 
%     whose key is given as fifth argument. 
%
%   MATISSE preserves the order of the successors in a relationship. Functions 
%   such as MtGetSuccessors retrieve the successors in the same order as they were 
%   stored.
%
%   Only the successors of a relationship defined in the model can be modified.
%
%   OUTPUT [1]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%   INPUT [4 or 5]
%
%      object: number
%          The key to an object. 
%
%      relationship: number or string
%          The key or the name of a relationship.
%
%      successor: number
%          The key to successor to be added. 
%
%      where: number or string
%          The location where the new successor must be added. 
%
%      element: number
%          The key to a successor in the existing list of successors. 
%
% See also:
%
%   MtAddSuccessors
%   MtGetAddedSuccessors 

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001   
