% MtGetListElements retrieve a subset of the list value of the attribute. 
%
%   [status, bufList, numElts] = ...
%      MtGetListElements (object, attribute, type, numElts, offset);
%
%   The subset to be retrieved begins at firstEltOffset and is at most numElts long.
%
%   The name of the attributes is not case sensitive. These functions can be called 
%   either inside a transaction or during a version access.
%
%   MATISSE internally manages an offset for each list value. This offset is set 
%   to firstEltOffset + numElts after every call to the MtGetListElements and
%   Mt SetListElements functions. It can be used for further access by specifying 
%   MT_CURRENT_OFFSET as value for the firstEltOffset argument. There is no default  
%   offset so MT_CURRENT_OFFSET cannot be specified at the first call.
%
%   The offset management remains coherent only within the same transaction or 
%   version access.
%
%   OUTPUT [3]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%      bufList: number
%          The key to the subset retrieved by the function. 
%
%      numElts: number
%          As output it indicates the exact number of elements of the subset. 
%
%   INPUT [5]
%
%      object: number
%          The key to an object. 
%
%      attribute: number or string
%          The key or the name of an attribute.
%
%      type: number or string
%          The expected type of the list value. Possible types are all of the format
%          'MT_*_LIST'.
%
%      numElts: number
%          As input, this parameter indicates the maximum number of elements to 
%          be read for the subset. 
%
%      offset: number or string
%          The offset (or position) of the first element of the subset to be retrieved. 
%          The first element in the list value has the offset 0.
%
%          Two specific values are allowed:
%          - 'MT_BEGIN_OFFSET',
%          - 'MT_CURRENT_OFFSET',
%         The last one means "the next element immediately after the last accessed 
%         element". 
%
% See also:
%   MtSetListElements
%   MtGetValue

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001   

