% MtGetSelection search for a selection.
%
%   [status, selection] = MtGetSelection;
%   [status, selection] = MtGetSelection (selectionName);
%
%   This function retrieves a selection by its name.
%
%   When the argument selectionName is not given, the function returns the 
%   unnamed selection of the current context if one exists.
%
%   If no selection is found, this function returns the error
%   MATISSE_NOSUCHSELECTION.
%
%   In most applications, only one selection is created and used at a time.
%   The naming of a selection is useful when working with
%   multiple selections.
%
%   OUTPUT [1]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%
%      selection: number
%         The key to a selection. 
%
%   INPUT [0 or 1]
%
%      selectionName: string (optional)
%         The name of the selection to be retrieved. 
%
%   See also: 
%      MatisseSQL
%
%   Example:
%   %  The following example shows how to obtain the current selection
%
%   [status, conn] = MtAllocateConnection;
%   status = MtConnectDatabase (conn, 'amelie.wins.uva.nl', 'Video501');
%   status = MtSetCurrentConnection (conn);
%
%   [status, stmt] = MtSQLAllocStmt;
%   [status, stmt] = MtSQLExecDirect (stmt, 'SELECT Title FROM Movie');
%
%   [status, selection] = MtGetSelection;
%   
%   ...
%
%   %   The following example should be equivalent (but doesn't work yet):
%
%   % [status, stmt] = MtSQLExecDirect (stmt, 'SELECT Title FROM Movie INTO MT');
%   %   The following example does work:
%
%   [status, stmt] = MtSQLExecDirect (stmt, 'SELECT Title FROM Movie');
%
%   status = MtSetSelectionName (selection, 'MT');
%   [status, selection] = MtGetSelection('MT');
%
%   status = MtSQLFreeStmt (stmt);
%   status = MtEndVersionAccess;
%   status = MtNoCurrentConnection;
%   status = MtDisconnectDatabase (conn);
%   status = MtFreeConnection (conn);

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 6.0.0.88 (R12) - Matisse 5.0.1
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    December 2001

