% MtGetSelectionName retrieves the name of a selection.
%
%   [status, selectionName] = MtGetSelectionName (selection);
%
%   If the selection passed in argument is not named, the value returned is NULL.
%
%   INPUT [1]
%      selection: number
%         The key to the selection produced by the successful
%         execution of a SQL SELECT ... INTO statement.
%
%   OUTPUT [2]
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise 'MATISSE_INVALARG' is returned.
%
%      selectionName: string
%          The name of the selection to be retrieved.
%            
%   Example:
%
%   [status, conn] = MtAllocateConnection;
%   status = MtConnectDatabase (conn, 'amelie.wins.uva.nl', 'Video501');
%   status = MtSetCurrentConnection (conn);
%
%   [status, stmt] = MtSQLAllocStmt;
%   [status, stmt] = MtSQLExecDirect (stmt, 'SELECT Title FROM Movie');
%   
%   status = MtSetSelectionName (selection, 'MT');
%   [status, selection] = MtGetSelection('MT');
%   [status, name] = MtGetSelectionName (selection)
%   
%   status = MtSQLFreeStmt (stmt);
%   status = MtEndVersionAccess;
%   status = MtNoCurrentConnection;
%   status = MtDisconnectDatabase (conn);

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 6.0.0.88 (R12) - Matisse 5.0.1
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    December 2001

