% MtOpenSelectionStream opens a stream that contains the objects of a selection.
%
%   [status, stream] = MtOpenSelectionStream (selection);
%
%   The stream that this function opens will contain the instances of the objects 
%   that were previously selected. The selection stream can be manipulated like any 
%   MATISSE stream. The instances can be retrieved with the function MtNextObject 
%   and the stream can be closed with the function MtCloseStream.
%
%   INPUT [1]
%      selection: number or string
%         The key or name of the selection to be renamed.
%
%   OUTPUT [2]
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise 'MATISSE_INVALARG' is returned.
%           
%      stream: number
%          The key to the object stream that will contain the instances meeting 
%          the selection criteria.
%
%   See also:
%      MatisseSQL
%
 
%   Example (MtOpenSelectionStream doesn't work):
%
%   colnum = 1;
%   [status, conn] = MtAllocateConnection;
%   status = MtConnectDatabase (conn, 'amelie.wins.uva.nl', 'Video501');
%   status = MtSetCurrentConnection (conn);
%
%   [status, stmt] = MtSQLAllocStmt;
%   [status, stmt] = MtSQLExecDirect (stmt, 'SELECT Title FROM Movie');
%
%   [status, selection] = MtGetSelection;
%   
%   [status, stream] = MtOpenSelectionStream (selection);
%   status = MtSQLNext (stream);
%
%   while strcmp (status, 'MATISSE_SUCCESS');
%
%        [status, type, title, size] = ...
%               MtSQLGetRowValue(stream, colnum, 'MT_STRING', 1, 1024);
%        title
%        status = MtSQLNext (stream);
%   end
%   
%   status = MtCloseStream (stream);
%   status = MtSQLFreeStmt (stmt);
%   status = MtEndVersionAccess;
%   status = MtNoCurrentConnection;
%   status = MtDisconnectDatabase (conn);
%   status = MtFreeConnection (conn);

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 6.0.0.88 (R12) - Matisse 5.0.1
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    December 2001

