% MtSQLExec Evaluates a SQL statement on a Matisse database.
%
%   [status, sqlResult] = MtSQLExec (sqlQuery);
%
%   INPUT [1]
%      sqlQuery: 1xn array of char
%         The sqlQuery starts with one of the keywords CONNECT, SELECT, etc.
%         For further details, see the Matisse SQL User Guide
%   OUTPUT [2]
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated.
%      sqlResult: 1x1 struct
%          sqlResult is a structure with seven fields:
%          * resultType: a number, indicating the kind of SQL statement executed
%          * selection:  a pointer to the result of a SELECT command.
%          * numberObjects: the number of objects selected or affected by the
%                           SELECT, INSERT, UPDATE, or DELETE command. 
%          * message: this the result-message or an error-message.
%          * errorLine: a number indicating the line number where a SQL-syntax
%                       error is made
%          * errorPosition: a number indicating the character position where a
%                           SQL-syntax error is made
%          * errorPosition: a code indicating the SQL error made
%           
%   Example:
%
%   [status, sqlResult] = ...
%          MtSQLExec ('CONNECT TO "VideoStore" AS FIRST');
%   [status, sqlResult] = ...
%          MtSQLExec ('SELECT * FROM MOVIE');
%   [status, sqlResult] = MtSQLExec ('ROLLBACK');
%   [status, sqlResult] = MtSQLExec ('DISCONNECT FIRST');
%
%   See also: MtSQLOpenSelectionStream

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001   
