% MtSQLExec Evaluates a SQL statement on a Matisse database.
%
%   [status, sqlResult] = MtSQLExec (sqlQuery);
%
%   INPUT [1]
%      sqlQuery: 1xn array of char
%         The sqlQuery starts with one of the keywords CONNECT, SELECT, etc.
%         For further details, see the Matisse SQL User Guide
%   OUTPUT [2]
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise 'MATISSE_SQLERROR' is returned.
%      sqlResult: 1x1 struct
%          sqlResult is a structure with seven fields:
%          * resultType: a number, indicating the kind of SQL statement executed
%          * selection:  a pointer to the result of a SELECT command.
%          * numberObjects: 
%          The first field (resultType) is a number. The second field (result)
%          is also a struct, with 10 fields. Only one of the 10 fields is filled,
%          dependend on the keyword used in the sqlQuery. The resultType indicates
%          which field is filled (0-9). 
%           
%   Example:
%
%   [status, conn] = MtAllocateConnection;
%   status = MtConnectDatabase (conn, 'amelie.wins.uva.nl', 'Video501');
%   status = MtSetCurrentConnection (conn);
%
%   [status, stmt] = MtSQLAllocStmt;
%   [status, stmt] = MtSQLExecDirect (stmt, 'SELECT Title FROM Movie');
%   status = MtSQLFreeStmt (stmt);
%   status = MtEndVersionAccess;
%   status = MtNoCurrentConnection;
%   status = MtDisconnectDatabase (conn);
%   status = MtFreeConnection (conn);
%
%   See also: MtSQLOpenSelectionStream

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 6.0.0.88 (R12) - Matisse 5.0.1
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    December 2001

