% MtSQLGetRowValue get the value of a given column from the current row.
%
%   [status, type, value, size] = MtSQLGetRowValue(stream, colnum, type, value, size);
%
%   This function returns the value of a given row. The function can also be 
%   called to retrieve information about this specific value, 
%   instead of the value itself. This is for instance convenient for 
%   attribute that can have values of multiple types.
%
%   OUTPUT [1 to 4]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%
%      type: number (optional)
%          The column type. When the third input argument is set to NULL, 
%          the function does not return the type. Currently implemented:
%		        MT_FLOAT
%             MT_DOUBLE
%             MT_TIMESTAMP
%             MT_S16
%             MT_S32
%             MT_KEY
%             MT_ASCII_CHAR
%             MT_CHAR
%             MT_NIL
%             MT_ASCII_STRING
%             MT_STRING
%
%      value: number (optional)
%          The value to be retrieved. When the fourth input argument is set
%          to NULL, the function does not return the value. 
%          This may prove useful, especially when the user is interested in the type, 
%          the dimension of the attribute value, or the size of this property.        
%
%      size: number (optional)
%          The size of the buffer for the value that is returned. When the stored 
%          value is NULL, then size is equal to 0.  When the fifth input argument   
%          is set to NULL, the function does not return the typesize. 
%
%   INPUT [5]
%
%      stream: number
%          A class stream, an entry-point stream, a relationship stream, 
%          a selection stream or an inverse relationship stream.
%
%      type: number or string
%          Two meanings:
%          - flag to indicate that no type information is needed (when NULL)
%          - the actual type of the value to be retrieved (when not NULL)
%
%      value: number
%          a flag to indicate if the value has to be retrieved. 
%
%      size: number 
%          Two meanings:
%          - flag to indicate that no sizee information is needed (when NULL)
%          - the actual size of the value to be retrieved (when not NULL)
%
%   See also: 
%      MatisseSQL

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001  
