% MtSQLGetSelection search for a selection.
%
%   [status, selection] = MtSQLGetSelection;
%   [status, selection] = MtSQLGetSelection (selectionName);
%
%   This function retrieves a selection by its name.
%
%   When the argument selectionName is not given, the function returns the 
%   unnamed selection of the current context if one exists.
%
%   If no selection is found, this function returns the error MATISSE_NOSUCHSELECTION.
%
%   In most applications, only one selection is created and used at a time. In this 
%   case the selection is simply obtained from the MtSQLResult structure returned 
%   by MtSQLExec. The MtSQLGetSelection function is useful when working with
%   multiple selections.
%
%   OUTPUT [1]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%
%      selection: number
%         The key to a selection. 
%
%   INPUT [0 or 1]
%
%      selectionName: string (optional)
%         The name of the selection to be retrieved. 
%
%   See also: 
%      MatisseSQL
%
%   Example:
%   %  The following example shows how to obtain a selection from MtSQLResult:
%
%   [status, sqlResult] = ...
%          MtSQLExec ('CONNECT TO "VideoStore"');
%   [status, sqlResult] = MtSQLExec ('SELECT Title FROM Movie INTO MT');
%
%   selection = sqlResult.selection;
%   
%   ...
%
%   %   The following example is equivalent:
%
%   [status, sqlResult] = ...
%          MtSQLExec ('CONNECT TO "VideoStore"');
%   [status, sqlResult] = MtSQLExec ('SELECT Title FROM Movie INTO MT');
%
%   [status, selection] = MtSQLGetSelection('MT');
%
%   status = MtSQLFreeSelection (selection);
%   [status, sqlResult] = MtSQLExec ('ROLLBACK');
%   [status, sqlResult] = MtSQLExec ('DISCONNECT CURRENT');

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001  
