% MtSQLGetSelectionNumberObjects retrieves the number of objects in a selection.
%
%   [status, numberObjects] = MtSQLGetSelectionNumberObjects;
%   [status, numberObjects] = MtSQLGetSelectionNumberObjects (selection);
%
%   If no selection argument is given, the function uses the unnamed selection of 
%   the currentcontext if one exists.
%
%   INPUT [1]
%      selection: number or string
%         The key or the name of the selection produced by the successful
%         execution of a SQL SELECT statement.
%
%   OUTPUT [2]
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise 'MATISSE_INVALARG' is returned.
%
%      numberObjects: number
%          The number of objects in the selection.
%           
%   Example:
%
%   % Equivalent with 
%
%   [status, sqlResult] = ...
%          MtSQLExec ('CONNECT TO "VideoStore"');
%   [status, sqlResult] = ...
%          MtSQLExec ('SELECT * FROM MOVIE INTO M');
%   numberObjects = sqlResult.numberObjects;
%   ...
%
%   % Is the usage of the function MtSQLGetSelectionNumberObjects
%
%   [status, sqlResult] = ...
%          MtSQLExec ('CONNECT TO "VideoStore"');
%   [status, sqlResult] = ...
%          MtSQLExec ('SELECT * FROM MOVIE INTO M');
%   
%   [status, numberObjects] = MtSQLGetSelectionNumberObjects ('M')
%   
%   [status, sqlResult] = MtSQLExec ('ROLLBACK');
%   [status, sqlResult] = MtSQLExec ('DISCONNECT CURRENT');

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001

