% MtStartTransaction starts a transaction with a priority to solve deadlocks. 
%
%   status = MtStartTransaction (priority);
%
%   A transaction is the smallest granularity operation on a database. It is atomic: 
%   all the elements of the transaction either succeed or fail. If they fail, the 
%   transaction is aborted. Abort may be initiated by the server or by the user.
%
%   Within a transaction, access to the database may be blocked for various reasons:
%
%   - If competing transactions mutually prohibit access (deadlock), one of the 
%     transactions is aborted (depending on transaction priority); 
%   - If the wait-time is not respected or if a MATISSE error occurs, an error 
%     status is returned. 
%
%   When getting out of a transaction, the cache is flushed: all objects read into 
%   client memory during the transaction are deleted, and all the locks on these 
%   objects are released.
%
%   A transaction is related to a single connection only.
%
%   The more a transaction modifies objects, the more locks are created. Therefore, 
%   transactions modifying objects should be as short as possible to avoid affecting 
%   other users.
%
%
%   OUTPUT [1]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%   INPUT [1]
%
%      priority: number
%         The value used by the server to solve access conflicts (in case of 
%         deadlock). The value is included between zero (lowest priority) and 
%         nine (highest priority). 
%
%   See also: 
%      MatisseAccess
%      MtAbortTransaction
%      MtCommitTransaction

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001

